//// [parserGreaterThanTokenAmbiguity20.ts]
1
// Before
>>>= // after
2;

//// [parserGreaterThanTokenAmbiguity20.js]
1
    >>>=
        2;
